==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgsDetail");
        }
        static d(a) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.ad("WebPaneHeaderConnectionEventArgs", () => new WebPaneHeaderConnectionEventArgsDescription());
            a.ac("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgsDetail");
        }
        static d(a) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.ae("WebPaneHeaderConnectionEventArgs", () => new WebPaneHeaderConnectionEventArgsDescription());
            a.ad("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
})();
